# mobileconfig

`mobileconfig` is a python3 module to parse `.mobileconfig` files for better examination.

Usage:

```
Usage: python -m mobileconfig [OPTIONS] DIRECTORY COMMAND [ARGS]...

  Parse .mobileconfig files in a given directory

Options:
  --help  Show this message and exit.

Commands:
  consents       Print all user consents
  extract        Extract .plist into given directory
  payload-types  Print all PayloadType's (with an optional .csv output)
```

